@@ -18,22 +18,24 @@
 #include <sys/types.h>
 #include <getopt.h>
 
-#include "alloc.h"
+#include "chkname.h"
 #include "defines.h"
+/*@-exitarg@*/
+#include "exitcodes.h"
 #include "getdef.h"
 #include "nscd.h"
-#include "sssd.h"
 #ifdef USE_PAM
 #include "pam_defs.h"
 #endif
 #include "prototypes.h"
 #include "pwauth.h"
 #include "pwio.h"
-/*@-exitarg@*/
-#include "exitcodes.h"
 #include "shadowlog.h"
-#include "string/sprintf.h"
-#include "string/strtcpy.h"
+#include "sssd.h"
+#include "string/sprintf/snprintf.h"
+#include "string/strcmp/streq.h"
+#include "string/strcpy/strtcpy.h"
+#include "string/strdup/xstrdup.h"
 
 
 /*
@@ -150,9 +152,9 @@ static bool may_change_field (int field)
 	cp = getdef_str ("CHFN_RESTRICT");
 	if (NULL == cp) {
 		cp = "";
-	} else if (strcmp (cp, "yes") == 0) {
+	} else if (streq(cp, "yes")) {
 		cp = "rwh";
-	} else if (strcmp (cp, "no") == 0) {
+	} else if (streq(cp, "no")) {
 		cp = "frwh";
 	}
 
@@ -214,32 +216,27 @@ static void new_fields (void)
  */
 static char *copy_field (char *in, char *out, char *extra)
 {
-	char *cp = NULL;
-
 	while (NULL != in) {
-		cp = strchr (in, ',');
-		if (NULL != cp) {
-			*cp++ = '\0';
-		}
+		char  *f;
 
-		if (strchr (in, '=') == NULL) {
+		f = strsep(&in, ",");
+
+		if (strchr(f, '=') == NULL)
 			break;
-		}
 
 		if (NULL != extra) {
-			if ('\0' != extra[0]) {
+			if (!streq(extra, "")) {
 				strcat (extra, ",");
 			}
 
-			strcat (extra, in);
+			strcat(extra, f);
 		}
-		in = cp;
 	}
 	if ((NULL != in) && (NULL != out)) {
 		strcpy (out, in);
 	}
 
-	return cp;
+	return in;
 }
 
 /*
@@ -546,7 +543,7 @@ static void get_old_fields (const char *gecos)
 	 * Anything left over is "slop".
 	 */
 	if ((NULL != cp) && !oflg) {
-		if ('\0' != slop[0]) {
+		if (!streq(slop, "")) {
 			strcat (slop, ",");
 		}
 
@@ -648,6 +645,10 @@ int main (int argc, char **argv)
 	 * name, or the name getlogin() returns.
 	 */
 	if (optind < argc) {
+		if (!is_valid_user_name (argv[optind])) {
+			fprintf (stderr, _("%s: Provided user name is not a valid name\n"), Prog);
+			fail_exit (E_NOPERM);
+		}
 		user = argv[optind];
 		pw = xgetpwnam (user);
 		if (NULL == pw) {
@@ -701,7 +702,7 @@ int main (int argc, char **argv)
 	}
 	SNPRINTF(new_gecos, "%s,%s,%s,%s%s%s",
 	         fullnm, roomno, workph, homeph,
-	         ('\0' != slop[0]) ? "," : "", slop);
+	         (!streq(slop, "")) ? "," : "", slop);
 
 	/* Rewrite the user's gecos in the passwd file */
 	update_gecos (user, new_gecos);
