@@ -1,12 +1,16 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
 
+
 #include <stdio.h>
 #include <unistd.h>
+
+#include "atoi/str2i/str2u.h"
 #include "subid.h"
 #include "stdlib.h"
 #include "prototypes.h"
 #include "shadowlog.h"
 
+
 /* Test program for the subid freeing routine */
 
 static const char Prog[] = "free_subid_range";
@@ -38,8 +42,8 @@ int main(int argc, char *argv[])
 	if (argc < 3)
 		usage();
 	range.owner = argv[0];
-	range.start = atoi(argv[1]);
-	range.count = atoi(argv[2]);
+	str2ul(&range.start, argv[1]);
+	str2ul(&range.count, argv[2]);
 	if (group)
 		ok = subid_ungrant_gid_range(&range);
 	else
